Discover Packages
github.com/retlehs/ansimotd
internal
api
package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Apr 12, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
DownloadAndExtract downloads a pack archive and extracts ANSI files to destDir.
Returns true if the pack was downloaded, false if skipped (already exists).
type Pack struct {
Year int `json:"year"`
Name flexString `json:"name"`
Download string `json:"download"`
Groups []flexString `json:"groups"`
}
Pack represents an art pack from the API.
FetchPacks retrieves all packs for a given year, applying optional filters.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.